@@ -55,7 +55,7 @@ class Cache:
 
         async_chunk_size = self.redis_root.async_db_requests_limit
         redis_instances_django_ids = []
-        for redis_instance in self.all_redis_instances:
+        for redis_instance_id, redis_instance in self.all_redis_instances.items():
             if 'django_id' in redis_instance.keys():
                 django_id = redis_instance['django_id']
                 if django_id not in ['null', None]:
